@@ -3,6 +3,8 @@ import gdown
 from pathlib import Path
 import zipfile
 
+from deepface.commons import functions
+
 import tensorflow as tf
 tf_version = int(tf.__version__.split(".")[0])
 
@@ -49,7 +51,7 @@ def loadModel(url = 'https://github.com/serengil/deepface_models/releases/downlo
 
 	#----------------------------
 
-	home = str(Path.home())
+	home = functions.get_deepface_home()
 
 	if os.path.isfile(home+'/.deepface/weights/facial_expression_model_weights.h5') != True:
 		print("facial_expression_model_weights.h5 will be downloaded...")
